"use strict";

var _utils = require("@typescript-eslint/utils");
var _dedent = _interopRequireDefault(require("dedent"));
var _noConditionalInTest = _interopRequireDefault(require("../no-conditional-in-test"));
var _testUtils = require("./test-utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const ruleTester = new _utils.TSESLint.RuleTester({
  parser: _testUtils.espreeParser,
  parserOptions: {
    ecmaVersion: 2015
  }
});
ruleTester.run('conditional expressions', _noConditionalInTest.default, {
  valid: ['const x = y ? 1 : 0', (0, _dedent.default)`
      const foo = function (bar) {
        return foo ? bar : null;
      };

      it('foo', () => {
        foo();
      });
    `, (0, _dedent.default)`
      const foo = function (bar) {
        return foo ? bar : null;
      };

      it.each()('foo', function () {
        foo();
      });
    `, (0, _dedent.default)`
      fit.concurrent('foo', () => {
        switch('bar') {}
      })
    `],
  invalid: [{
    code: (0, _dedent.default)`
        it('foo', () => {
          expect(bar ? foo : baz).toBe(boo);
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 10,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        it('foo', function () {
          const foo = function (bar) {
            return foo ? bar : null;
          };
        });
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 12,
      line: 3
    }]
  }, {
    code: (0, _dedent.default)`
        it('foo', () => {
          const foo = bar ? foo : baz;
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 15,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        it('foo', () => {
          const foo = bar ? foo : baz;
        })
        const foo = bar ? foo : baz;
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 15,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        it('foo', () => {
          const foo = bar ? foo : baz;
          const anotherFoo = anotherBar ? anotherFoo : anotherBaz;
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 15,
      line: 2
    }, {
      messageId: 'conditionalInTest',
      column: 22,
      line: 3
    }]
  }]
});
ruleTester.run('switch statements', _noConditionalInTest.default, {
  valid: [`it('foo', () => {})`, (0, _dedent.default)`
      switch (true) {
        case true: {}
      }
    `, (0, _dedent.default)`
      it('foo', () => {});
      function myTest() {
        switch ('bar') {
        }
      }
    `, (0, _dedent.default)`
      foo('bar', () => {
        switch(baz) {}
      })
    `, (0, _dedent.default)`
      describe('foo', () => {
        switch('bar') {}
      })
    `, (0, _dedent.default)`
      describe.skip('foo', () => {
        switch('bar') {}
      })
    `, (0, _dedent.default)`
      describe.skip.each()('foo', () => {
        switch('bar') {}
      })
    `, (0, _dedent.default)`
      xdescribe('foo', () => {
        switch('bar') {}
      })
    `, (0, _dedent.default)`
      fdescribe('foo', () => {
        switch('bar') {}
      })
    `, (0, _dedent.default)`
      describe('foo', () => {
        switch('bar') {}
      })
      switch('bar') {}
    `, (0, _dedent.default)`
      describe('foo', () => {
        afterEach(() => {
          switch('bar') {}
        });
      });
    `, (0, _dedent.default)`
      const values = something.map(thing => {
        switch (thing.isFoo) {
          case true:
            return thing.foo;
          default:
            return thing.bar;
        }
      });

      it('valid', () => {
        expect(values).toStrictEqual(['foo']);
      });
    `, (0, _dedent.default)`
      describe('valid', () => {
        const values = something.map(thing => {
          switch (thing.isFoo) {
            case true:
              return thing.foo;
            default:
              return thing.bar;
          }
        });
        it('still valid', () => {
          expect(values).toStrictEqual(['foo']);
        });
      });
    `],
  invalid: [{
    code: (0, _dedent.default)`
        it('is invalid', () => {
          const values = something.map(thing => {
            switch (thing.isFoo) {
              case true:
                return thing.foo;
              default:
                return thing.bar;
            }
          });

          expect(values).toStrictEqual(['foo']);
        });
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 5,
      line: 3
    }]
  }, {
    code: (0, _dedent.default)`
        it('foo', () => {
          switch (true) {
            case true: {}
          }
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        it('foo', () => {
          switch('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        it.skip('foo', () => {
          switch('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        it.only('foo', () => {
          switch('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        xit('foo', () => {
          switch('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        fit('foo', () => {
          switch('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        test('foo', () => {
          switch('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        test.skip('foo', () => {
          switch('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        test.only('foo', () => {
          switch('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        xtest('foo', () => {
          switch('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        xtest('foo', function () {
          switch('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        describe('foo', () => {
          it('bar', () => {

            switch('bar') {}
          })
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 5,
      line: 4
    }]
  }, {
    code: (0, _dedent.default)`
        describe('foo', () => {
          it('bar', () => {
            switch('bar') {}
          })
          it('baz', () => {
            switch('qux') {}
            switch('quux') {}
          })
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 5,
      line: 3
    }, {
      messageId: 'conditionalInTest',
      column: 5,
      line: 6
    }, {
      messageId: 'conditionalInTest',
      column: 5,
      line: 7
    }]
  }, {
    code: (0, _dedent.default)`
        it('foo', () => {
          callExpression()
          switch ('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 3
    }]
  }, {
    code: (0, _dedent.default)`
        describe('valid', () => {
          describe('still valid', () => {
            it('is not valid', () => {
              const values = something.map((thing) => {
                switch (thing.isFoo) {
                  case true:
                    return thing.foo;
                  default:
                    return thing.bar;
                }
              });
  
              switch('invalid') {
                case true:
                  expect(values).toStrictEqual(['foo']);
              }
            });
          });
        });
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 9,
      line: 5
    }, {
      messageId: 'conditionalInTest',
      column: 7,
      line: 13
    }]
  }]
});
ruleTester.run('if statements', _noConditionalInTest.default, {
  valid: ['if (foo) {}', "it('foo', () => {})", 'it("foo", function () {})', "it('foo', () => {}); function myTest() { if ('bar') {} }", (0, _dedent.default)`
      foo('bar', () => {
        if (baz) {}
      })
    `, (0, _dedent.default)`
      describe('foo', () => {
        if ('bar') {}
      })
    `, (0, _dedent.default)`
      describe.skip('foo', () => {
        if ('bar') {}
      })
    `, (0, _dedent.default)`
      xdescribe('foo', () => {
        if ('bar') {}
      })
    `, (0, _dedent.default)`
      fdescribe('foo', () => {
        if ('bar') {}
      })
    `, (0, _dedent.default)`
      describe('foo', () => {
        if ('bar') {}
      })
      if ('baz') {}
    `, (0, _dedent.default)`
      describe('foo', () => {
        afterEach(() => {
          if ('bar') {}
        });
      })
    `, (0, _dedent.default)`
      describe.each\`\`('foo', () => {
        afterEach(() => {
          if ('bar') {}
        });
      })
    `, (0, _dedent.default)`
      describe('foo', () => {
        beforeEach(() => {
          if ('bar') {}
        });
      })
    `, 'const foo = bar ? foo : baz;', (0, _dedent.default)`
      const values = something.map((thing) => {
        if (thing.isFoo) {
          return thing.foo
        } else {
          return thing.bar;
        }
      });

      describe('valid', () => {
        it('still valid', () => {
          expect(values).toStrictEqual(['foo']);
        });
      });
    `, (0, _dedent.default)`
      describe('valid', () => {
        const values = something.map((thing) => {
          if (thing.isFoo) {
            return thing.foo
          } else {
            return thing.bar;
          }
        });

        describe('still valid', () => {
          it('really still valid', () => {
            expect(values).toStrictEqual(['foo']);
          });
        });
      });
    `, (0, _dedent.default)`
      fit.concurrent('foo', () => {
        if ('bar') {}
      })
    `],
  invalid: [{
    code: (0, _dedent.default)`
        it('foo', () => {
          const foo = function(bar) {
            if (bar) {
              return 1;
            } else {
              return 2;
            }
          };
        });
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 5,
      line: 3
    }]
  }, {
    code: (0, _dedent.default)`
        it('foo', () => {
          function foo(bar) {
            if (bar) {
              return 1;
            } else {
              return 2;
            }
          };
        });
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 5,
      line: 3
    }]
  }, {
    code: (0, _dedent.default)`
        it('foo', () => {
          if ('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        it.skip('foo', () => {
          if ('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        it.skip('foo', function () {
          if ('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        it.only('foo', () => {
          if ('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        xit('foo', () => {
          if ('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        fit('foo', () => {
          if ('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        test('foo', () => {
          if ('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        test.skip('foo', () => {
          if ('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        test.only('foo', () => {
          if ('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        xtest('foo', () => {
          if ('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        describe('foo', () => {
          it('bar', () => {
            if ('bar') {}
          })
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 5,
      line: 3
    }]
  }, {
    code: (0, _dedent.default)`
        describe('foo', () => {
          it('bar', () => {
            if ('bar') {}
          })
          it('baz', () => {
            if ('qux') {}
            if ('quux') {}
          })
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 5,
      line: 3
    }, {
      messageId: 'conditionalInTest',
      column: 5,
      line: 6
    }, {
      messageId: 'conditionalInTest',
      column: 5,
      line: 7
    }]
  }, {
    code: (0, _dedent.default)`
        it('foo', () => {
          callExpression()
          if ('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 3
    }]
  }, {
    code: (0, _dedent.default)`
        it.each\`\`('foo', () => {
          callExpression()
          if ('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 3
    }]
  }, {
    code: (0, _dedent.default)`
        it.each()('foo', () => {
          callExpression()
          if ('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 3
    }]
  }, {
    code: (0, _dedent.default)`
        it.only.each\`\`('foo', () => {
          callExpression()
          if ('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 3
    }]
  }, {
    code: (0, _dedent.default)`
        it.only.each()('foo', () => {
          callExpression()
          if ('bar') {}
        })
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 3
    }]
  }, {
    code: (0, _dedent.default)`
        describe('valid', () => {
          describe('still valid', () => {
            it('is invalid', () => {
              const values = something.map((thing) => {
                if (thing.isFoo) {
                  return thing.foo
                } else {
                  return thing.bar;
                }
              });

              if ('invalid') {
                expect(values).toStrictEqual(['foo']);
              }
            });
          });
        });
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 9,
      line: 5
    }, {
      messageId: 'conditionalInTest',
      column: 7,
      line: 12
    }]
  }, {
    code: (0, _dedent.default)`
        test("shows error", () => {
          if (1 === 2) {
            expect(true).toBe(false);
          }
        });

        test("does not show error", () => {
          setTimeout(() => console.log("noop"));
          if (1 === 2) {
            expect(true).toBe(false);
          }
        });
      `,
    errors: [{
      messageId: 'conditionalInTest',
      column: 3,
      line: 2
    }, {
      messageId: 'conditionalInTest',
      column: 3,
      line: 9
    }]
  }]
});