"use strict";

var _utils = require("@typescript-eslint/utils");
var _dedent = _interopRequireDefault(require("dedent"));
var _noExport = _interopRequireDefault(require("../no-export"));
var _testUtils = require("./test-utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const ruleTester = new _utils.TSESLint.RuleTester({
  parser: _testUtils.espreeParser,
  parserOptions: {
    ecmaVersion: 2015,
    sourceType: 'module'
  }
});
ruleTester.run('no-export', _noExport.default, {
  valid: ['describe("a test", () => { expect(1).toBe(1); })', 'window.location = "valid"', 'module.somethingElse = "foo";', 'export const myThing = "valid"', 'export default function () {}', 'module.exports = function(){}', 'module.exports.myThing = "valid";'],
  invalid: [{
    code: 'export const myThing = "invalid"; test("a test", () => { expect(1).toBe(1);});',
    parserOptions: {
      sourceType: 'module'
    },
    errors: [{
      endColumn: 34,
      column: 1,
      messageId: 'unexpectedExport'
    }]
  }, {
    code: (0, _dedent.default)`
        export const myThing = 'invalid';

        test.each()('my code', () => {
          expect(1).toBe(1);
        });
      `,
    parserOptions: {
      sourceType: 'module'
    },
    errors: [{
      endColumn: 34,
      column: 1,
      messageId: 'unexpectedExport'
    }]
  }, {
    code: (0, _dedent.default)`
        export const myThing = 'invalid';

        test.each\`\`('my code', () => {
          expect(1).toBe(1);
        });
      `,
    parserOptions: {
      sourceType: 'module'
    },
    errors: [{
      endColumn: 34,
      column: 1,
      messageId: 'unexpectedExport'
    }]
  }, {
    code: (0, _dedent.default)`
        export const myThing = 'invalid';

        test.only.each\`\`('my code', () => {
          expect(1).toBe(1);
        });
      `,
    parserOptions: {
      sourceType: 'module'
    },
    errors: [{
      endColumn: 34,
      column: 1,
      messageId: 'unexpectedExport'
    }]
  }, {
    code: 'export default function() {};  test("a test", () => { expect(1).toBe(1);});',
    parserOptions: {
      sourceType: 'module'
    },
    errors: [{
      endColumn: 29,
      column: 1,
      messageId: 'unexpectedExport'
    }]
  }, {
    code: 'module.exports["invalid"] = function() {};  test("a test", () => { expect(1).toBe(1);});',
    errors: [{
      endColumn: 26,
      column: 1,
      messageId: 'unexpectedExport'
    }]
  }, {
    code: 'module.exports = function() {}; ;  test("a test", () => { expect(1).toBe(1);});',
    errors: [{
      endColumn: 15,
      column: 1,
      messageId: 'unexpectedExport'
    }]
  }, {
    code: 'module.export.invalid = function() {}; ;  test("a test", () => { expect(1).toBe(1);});',
    errors: [{
      endColumn: 22,
      column: 1,
      messageId: 'unexpectedExport'
    }]
  }]
});