"use strict";

var _utils = require("@typescript-eslint/utils");
var _noInterpolationInSnapshots = _interopRequireDefault(require("../no-interpolation-in-snapshots"));
var _testUtils = require("./test-utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const ruleTester = new _utils.TSESLint.RuleTester({
  parser: _testUtils.espreeParser,
  parserOptions: {
    ecmaVersion: 2017
  }
});
ruleTester.run('no-interpolation-in-snapshots', _noInterpolationInSnapshots.default, {
  valid: ['expect("something").toEqual("else");', 'expect(something).toMatchInlineSnapshot();', 'expect(something).toMatchInlineSnapshot(`No interpolation`);', 'expect(something).toMatchInlineSnapshot({}, `No interpolation`);', 'expect(something);', 'expect(something).not;', 'expect.toHaveAssertions();', 'myObjectWants.toMatchInlineSnapshot({}, `${interpolated}`);', 'myObjectWants.toMatchInlineSnapshot({}, `${interpolated1} ${interpolated2}`);', 'toMatchInlineSnapshot({}, `${interpolated}`);', 'toMatchInlineSnapshot({}, `${interpolated1} ${interpolated2}`);', 'expect(something).toThrowErrorMatchingInlineSnapshot();', 'expect(something).toThrowErrorMatchingInlineSnapshot(`No interpolation`);'],
  invalid: [{
    code: 'expect(something).toMatchInlineSnapshot(`${interpolated}`);',
    errors: [{
      endColumn: 58,
      column: 41,
      messageId: 'noInterpolation'
    }]
  }, {
    code: 'expect(something).not.toMatchInlineSnapshot(`${interpolated}`);',
    errors: [{
      endColumn: 62,
      column: 45,
      messageId: 'noInterpolation'
    }]
  }, {
    code: 'expect(something).toMatchInlineSnapshot({}, `${interpolated}`);',
    errors: [{
      endColumn: 62,
      column: 45,
      messageId: 'noInterpolation'
    }]
  }, {
    code: 'expect(something).not.toMatchInlineSnapshot({}, `${interpolated}`);',
    errors: [{
      endColumn: 66,
      column: 49,
      messageId: 'noInterpolation'
    }]
  }, {
    code: 'expect(something).toThrowErrorMatchingInlineSnapshot(`${interpolated}`);',
    errors: [{
      endColumn: 71,
      column: 54,
      messageId: 'noInterpolation'
    }]
  }, {
    code: 'expect(something).not.toThrowErrorMatchingInlineSnapshot(`${interpolated}`);',
    errors: [{
      endColumn: 75,
      column: 58,
      messageId: 'noInterpolation'
    }]
  }]
});