"use strict";

var _utils = require("@typescript-eslint/utils");
var _dedent = _interopRequireDefault(require("dedent"));
var _preferHooksInOrder = _interopRequireDefault(require("../prefer-hooks-in-order"));
var _testUtils = require("./test-utils");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const ruleTester = new _utils.TSESLint.RuleTester({
  parser: _testUtils.espreeParser,
  parserOptions: {
    ecmaVersion: 2015
  }
});
ruleTester.run('prefer-hooks-in-order', _preferHooksInOrder.default, {
  valid: ['beforeAll(() => {})', 'beforeEach(() => {})', 'afterEach(() => {})', 'afterAll(() => {})', 'describe(() => {})', (0, _dedent.default)`
      beforeAll(() => {});
      beforeEach(() => {});
      afterEach(() => {});
      afterAll(() => {});
    `, (0, _dedent.default)`
      describe('foo', () => {
        someSetupFn();
        beforeEach(() => {});
        afterEach(() => {});

        test('bar', () => {
          someFn();
        });
      });
    `, (0, _dedent.default)`
      beforeAll(() => {});
      afterAll(() => {});
    `, (0, _dedent.default)`
      beforeEach(() => {});
      afterEach(() => {});
    `, (0, _dedent.default)`
      beforeAll(() => {});
      afterEach(() => {});
    `, (0, _dedent.default)`
      beforeAll(() => {});
      beforeEach(() => {});
    `, (0, _dedent.default)`
      afterEach(() => {});
      afterAll(() => {});
    `, (0, _dedent.default)`
      beforeAll(() => {});
      beforeAll(() => {});
    `, (0, _dedent.default)`
      describe('my test', () => {
        afterEach(() => {});
        afterAll(() => {});
      });
    `, (0, _dedent.default)`
      describe('my test', () => {
        afterEach(() => {});
        afterAll(() => {});

        doSomething();

        beforeAll(() => {});
        beforeEach(() => {});
      });
    `, (0, _dedent.default)`
      describe('my test', () => {
        afterEach(() => {});
        afterAll(() => {});

        it('is a test', () => {});

        beforeAll(() => {});
        beforeEach(() => {});
      });
    `, (0, _dedent.default)`
      describe('my test', () => {
        afterAll(() => {});

        describe('when something is true', () => {
          beforeAll(() => {});
          beforeEach(() => {});
        });
      });
    `, (0, _dedent.default)`
      describe('my test', () => {
        afterAll(() => {});

        describe('when something is true', () => {
          beforeAll(() => {});
          beforeEach(() => {});

          it('does something', () => {});

          beforeAll(() => {});
          beforeEach(() => {});
        });

        beforeAll(() => {});
        beforeEach(() => {});
      });

      describe('my test', () => {
        beforeAll(() => {});
        beforeEach(() => {});
        afterAll(() => {});

        describe('when something is true', () => {
          it('does something', () => {});

          beforeAll(() => {});
          beforeEach(() => {});
        });

        beforeAll(() => {});
        beforeEach(() => {});
      });
    `, (0, _dedent.default)`
      const withDatabase = () => {
        beforeAll(() => {
          createMyDatabase();
        });
        afterAll(() => {
          removeMyDatabase();
        });
      };

      describe('my test', () => {
        withDatabase();

        afterAll(() => {});

        describe('when something is true', () => {
          beforeAll(() => {});
          beforeEach(() => {});

          it('does something', () => {});

          beforeAll(() => {});
          beforeEach(() => {});
        });

        beforeAll(() => {});
        beforeEach(() => {});
      });

      describe('my test', () => {
        beforeAll(() => {});
        beforeEach(() => {});
        afterAll(() => {});

        withDatabase();

        describe('when something is true', () => {
          it('does something', () => {});

          beforeAll(() => {});
          beforeEach(() => {});
        });

        beforeAll(() => {});
        beforeEach(() => {});
      });
    `, (0, _dedent.default)`
      describe('foo', () => {
        beforeAll(() => {
          createMyDatabase();
        });
      
        beforeEach(() => {
          seedMyDatabase();
        });
      
        it('accepts this input', () => {
          // ...
        });
      
        it('returns that value', () => {
          // ...
        });
      
        describe('when the database has specific values', () => {
          const specificValue = '...';
      
          beforeEach(() => {
            seedMyDatabase(specificValue);
          });
      
          it('accepts that input', () => {
            // ...
          });
      
          it('throws an error', () => {
            // ...
          });
      
          beforeEach(() => {
            mockLogger();
          });
      
          afterEach(() => {
            clearLogger();
          });
      
          it('logs a message', () => {
            // ...
          });
        });
      
        afterAll(() => {
          removeMyDatabase();
        });
      });
    `, (0, _dedent.default)`
      describe('A file with a lot of test', () => {
        beforeAll(() => {
          setupTheDatabase();
          createMocks();
        });
        
        beforeAll(() => {
          doEvenMore();
        });
        
        beforeEach(() => {
          cleanTheDatabase();
          resetSomeThings();
        });
        
        afterEach(() => {
          cleanTheDatabase();
          resetSomeThings();
        });
        
        afterAll(() => {
          closeTheDatabase();
          stop();
        });
        
        it('does something', () => {
          const thing = getThing();
          expect(thing).toBe('something');
        });
        
        it('throws', () => {
          // Do something that throws
        });
        
        describe('Also have tests in here', () => {
          afterAll(() => {});
          it('tests something', () => {});
          it('tests something else', () => {});
          beforeAll(()=>{});
        });
      });
    `],
  invalid: [{
    code: (0, _dedent.default)`
        const withDatabase = () => {
          afterAll(() => {
            removeMyDatabase();
          });
          beforeAll(() => {
            createMyDatabase();
          });
        };
      `,
    errors: [{
      messageId: 'reorderHooks',
      data: {
        currentHook: 'beforeAll',
        previousHook: 'afterAll'
      },
      column: 3,
      line: 5
    }]
  }, {
    code: (0, _dedent.default)`
        afterAll(() => {
          removeMyDatabase();
        });
        beforeAll(() => {
          createMyDatabase();
        });
      `,
    errors: [{
      messageId: 'reorderHooks',
      data: {
        currentHook: 'beforeAll',
        previousHook: 'afterAll'
      },
      column: 1,
      line: 4
    }]
  }, {
    code: (0, _dedent.default)`
        afterAll(() => {});
        beforeAll(() => {});
      `,
    errors: [{
      messageId: 'reorderHooks',
      data: {
        currentHook: 'beforeAll',
        previousHook: 'afterAll'
      },
      column: 1,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        afterEach(() => {});
        beforeEach(() => {});
      `,
    errors: [{
      // 'beforeEach' hooks should be before any 'afterEach' hooks
      messageId: 'reorderHooks',
      data: {
        currentHook: 'beforeEach',
        previousHook: 'afterEach'
      },
      column: 1,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        afterEach(() => {});
        beforeAll(() => {});
      `,
    errors: [{
      // 'beforeAll' hooks should be before any 'afterEach' hooks
      messageId: 'reorderHooks',
      data: {
        currentHook: 'beforeAll',
        previousHook: 'afterEach'
      },
      column: 1,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        beforeEach(() => {});
        beforeAll(() => {});
      `,
    errors: [{
      messageId: 'reorderHooks',
      data: {
        currentHook: 'beforeAll',
        previousHook: 'beforeEach'
      },
      column: 1,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        afterAll(() => {});
        afterEach(() => {});
      `,
    errors: [{
      messageId: 'reorderHooks',
      data: {
        currentHook: 'afterEach',
        previousHook: 'afterAll'
      },
      column: 1,
      line: 2
    }]
  }, {
    code: (0, _dedent.default)`
        afterAll(() => {});
        // The afterEach should do this
        // This comment does not matter for the order
        afterEach(() => {});
      `,
    errors: [{
      messageId: 'reorderHooks',
      data: {
        currentHook: 'afterEach',
        previousHook: 'afterAll'
      },
      column: 1,
      line: 4
    }]
  }, {
    code: (0, _dedent.default)`
        afterAll(() => {});
        afterAll(() => {});
        afterEach(() => {});
      `,
    errors: [{
      messageId: 'reorderHooks',
      data: {
        currentHook: 'afterEach',
        previousHook: 'afterAll'
      },
      column: 1,
      line: 3
    }]
  }, {
    code: (0, _dedent.default)`
        describe('my test', () => {
          afterAll(() => {});
          afterEach(() => {});
        });
      `,
    errors: [{
      messageId: 'reorderHooks',
      data: {
        currentHook: 'afterEach',
        previousHook: 'afterAll'
      },
      column: 3,
      line: 3
    }]
  }, {
    code: (0, _dedent.default)`
        describe('my test', () => {
          afterAll(() => {});
          afterEach(() => {});

          doSomething();

          beforeEach(() => {});
          beforeAll(() => {});
        });
      `,
    errors: [{
      messageId: 'reorderHooks',
      data: {
        currentHook: 'afterEach',
        previousHook: 'afterAll'
      },
      column: 3,
      line: 3
    }, {
      messageId: 'reorderHooks',
      data: {
        currentHook: 'beforeAll',
        previousHook: 'beforeEach'
      },
      column: 3,
      line: 8
    }]
  }, {
    code: (0, _dedent.default)`
        describe('my test', () => {
          afterAll(() => {});
          afterEach(() => {});

          it('is a test', () => {});

          beforeEach(() => {});
          beforeAll(() => {});
        });
      `,
    errors: [{
      messageId: 'reorderHooks',
      data: {
        currentHook: 'afterEach',
        previousHook: 'afterAll'
      },
      column: 3,
      line: 3
    }, {
      messageId: 'reorderHooks',
      data: {
        currentHook: 'beforeAll',
        previousHook: 'beforeEach'
      },
      column: 3,
      line: 8
    }]
  }, {
    code: (0, _dedent.default)`
        describe('my test', () => {
          afterAll(() => {});

          describe('when something is true', () => {
            beforeEach(() => {});
            beforeAll(() => {});
          });
        });
      `,
    errors: [{
      messageId: 'reorderHooks',
      data: {
        currentHook: 'beforeAll',
        previousHook: 'beforeEach'
      },
      column: 5,
      line: 6
    }]
  }, {
    code: (0, _dedent.default)`
        describe('my test', () => {
          beforeAll(() => {});
          afterAll(() => {});
          beforeAll(() => {});

          describe('when something is true', () => {
            beforeAll(() => {});
            afterEach(() => {});
            beforeEach(() => {});
            afterEach(() => {});
          });
        });
      `,
    errors: [{
      messageId: 'reorderHooks',
      data: {
        currentHook: 'beforeAll',
        previousHook: 'afterAll'
      },
      column: 3,
      line: 4
    }, {
      messageId: 'reorderHooks',
      data: {
        currentHook: 'beforeEach',
        previousHook: 'afterEach'
      },
      column: 5,
      line: 9
    }]
  }, {
    code: (0, _dedent.default)`
        describe('my test', () => {
          beforeAll(() => {});
          beforeAll(() => {});
          afterAll(() => {});
          
          it('foo nested', () => {
            // this is a test
          });

          describe('when something is true', () => {
            beforeAll(() => {});
            afterEach(() => {});
            
            it('foo nested', () => {
              // this is a test
            });
            
            describe('deeply nested', () => { 
              afterAll(() => {});
              afterAll(() => {});
              // This comment does nothing
              afterEach(() => {});
              
              it('foo nested', () => {
                // this is a test
              });
            })
            beforeEach(() => {});
            afterEach(() => {});
          });
        });
      `,
    errors: [{
      messageId: 'reorderHooks',
      data: {
        currentHook: 'afterEach',
        previousHook: 'afterAll'
      },
      column: 7,
      line: 22
    }]
  }, {
    code: (0, _dedent.default)`
        describe('my test', () => {
          const setupDatabase = () => {
            beforeEach(() => {
              initDatabase();
              fillWithData();
            });
            beforeAll(() => {
              setupMocks();
            });
          };
          
          it('foo', () => {
            // this is a test
          });
          
          describe('my nested test', () => {
            afterAll(() => {});
            afterEach(() => {});
            
            it('foo nested', () => {
              // this is a test
            });
          });
        });
      `,
    errors: [{
      messageId: 'reorderHooks',
      data: {
        currentHook: 'beforeAll',
        previousHook: 'beforeEach'
      },
      column: 5,
      line: 7
    }, {
      messageId: 'reorderHooks',
      data: {
        currentHook: 'afterEach',
        previousHook: 'afterAll'
      },
      column: 5,
      line: 18
    }]
  }, {
    code: (0, _dedent.default)`
        describe('foo', () => {
          beforeEach(() => {
            seedMyDatabase();
          });
        
          beforeAll(() => {
            createMyDatabase();
          });
        
          it('accepts this input', () => {
            // ...
          });
        
          it('returns that value', () => {
            // ...
          });
        
          describe('when the database has specific values', () => {
            const specificValue = '...';
        
            beforeEach(() => {
              seedMyDatabase(specificValue);
            });
        
            it('accepts that input', () => {
              // ...
            });
        
            it('throws an error', () => {
              // ...
            });
        
            afterEach(() => {
              clearLogger();
            });
            
            beforeEach(() => {
              mockLogger();
            });
        
            it('logs a message', () => {
              // ...
            });
          });
        
          afterAll(() => {
            removeMyDatabase();
          });
        });
      `,
    errors: [{
      messageId: 'reorderHooks',
      data: {
        currentHook: 'beforeAll',
        previousHook: 'beforeEach'
      },
      column: 3,
      line: 6
    }, {
      messageId: 'reorderHooks',
      data: {
        currentHook: 'beforeEach',
        previousHook: 'afterEach'
      },
      column: 5,
      line: 37
    }]
  }]
});